@@ -96,7 +96,7 @@ class HelpFormatter(IndentedHelpFormatter):
 
     def format_description(self, description):
         return text.ensure_2lines(text.fill_paragraphs(
-                text.dedent(description), self.width))
+            text.dedent(description), self.width))
 
 
 class Command(object):
@@ -134,6 +134,7 @@ class Command(object):
         Option('-b', '--broker', default=None),
         Option('--loader', default=None),
         Option('--config', default=None),
+        Option('--workdir', default=None, dest='working_directory'),
     )
 
     #: Enable if the application should support config from the cmdline.
@@ -221,8 +222,8 @@ class Command(object):
     def prepare_args(self, options, args):
         if options:
             options = dict((k, self.expanduser(v))
-                            for k, v in vars(options).iteritems()
-                                if not k.startswith('_'))
+                           for k, v in vars(options).iteritems()
+                           if not k.startswith('_'))
         args = map(self.expanduser, args)
         self.check_args(args)
         return options, args
@@ -248,14 +249,14 @@ class Command(object):
         return parser.parse_args(arguments)
 
     def create_parser(self, prog_name, command=None):
-        return self.prepare_parser(self.Parser(prog=prog_name,
-                           usage=self.usage(command),
-                           version=self.version,
-                           epilog=self.epilog,
-                           formatter=HelpFormatter(),
-                           description=self.description,
-                           option_list=(self.preload_options +
-                                        self.get_options())))
+        return self.prepare_parser(self.Parser(
+            prog=prog_name,
+            usage=self.usage(command),
+            version=self.version,
+            epilog=self.epilog,
+            formatter=HelpFormatter(),
+            description=self.description,
+            option_list=(self.preload_options + self.get_options())))
 
     def prepare_parser(self, parser):
         docs = [self.parse_doc(doc) for doc in (self.doc, __doc__) if doc]
@@ -266,22 +267,19 @@ class Command(object):
                     option.help = ' '.join(help) % {'default': option.default}
         return parser
 
-    def prepare_preload_options(self, options):
-        """Optional handler to do additional processing of preload options.
-
-        Configuration must not have been initialized
-        until after this is called.
-
-        """
-        pass
-
     def setup_app_from_commandline(self, argv):
         preload_options = self.parse_preload_options(argv)
-        self.prepare_preload_options(preload_options)
+        workdir = preload_options.get('working_directory')
+        if workdir:
+            os.chdir(workdir)
         app = (preload_options.get('app') or
                os.environ.get('CELERY_APP') or
                self.app)
-        loader = (preload_options.get('loader') or
+        preload_loader = preload_options.get('loader')
+        if preload_loader:
+            # Default app takes loader from this env (Issue #1066).
+            os.environ['CELERY_LOADER'] = preload_loader
+        loader = (preload_loader,
                   os.environ.get('CELERY_LOADER') or
                   'default')
         broker = preload_options.get('broker', None)
@@ -358,8 +356,8 @@ class Command(object):
                     in_option = m.groups()[0].strip()
                 assert in_option, 'missing long opt'
             elif in_option and line.startswith(' ' * 4):
-                options[in_option].append(find_rst_ref.sub(r'\1',
-                    line.strip()).replace('`', ''))
+                options[in_option].append(
+                    find_rst_ref.sub(r'\1', line.strip()).replace('`', ''))
         return options
 
     def with_pool_option(self, argv):
@@ -384,5 +382,4 @@ def daemon_options(default_pidfile=None, default_logfile=None):
         Option('--uid', default=None),
         Option('--gid', default=None),
         Option('--umask', default=0, type='int'),
-        Option('--workdir', default=None, dest='working_directory'),
     )
