@@ -35,9 +35,6 @@ WORKER_SIGIGNORE = frozenset(['SIGINT'])
 
 def process_initializer(app, hostname):
     """Initializes the process so it can be used to process tasks."""
-    app.set_current()
-    set_default_app(app)
-    trace._tasks = app._tasks  # make sure this optimization is set.
     platforms.signals.reset(*WORKER_SIGRESET)
     platforms.signals.ignore(*WORKER_SIGIGNORE)
     platforms.set_mp_process_title('celeryd', hostname=hostname)
@@ -50,8 +47,14 @@ def process_initializer(app, hostname):
                   str(os.environ.get('CELERY_LOG_REDIRECT_LEVEL')))
     app.loader.init_worker()
     app.loader.init_worker_process()
-    app.finalize()
-
+    if os.environ.get('FORKED_BY_MULTIPROCESSING'):
+        # pool did execv after fork
+        trace.setup_worker_optimizations(app)
+    else:
+        app.set_current()
+        set_default_app(app)
+        app.finalize()
+        trace._tasks = app._tasks  # enables fast_trace_task optimization.
     from celery.task.trace import build_tracer
     for name, task in app.tasks.iteritems():
         task.__trace__ = build_tracer(name, task, app.loader, hostname)
@@ -142,4 +145,4 @@ class TaskPool(BasePool):
 
     @property
     def timers(self):
-        return {self.maintain_pool: 30.0}
+        return {self.maintain_pool: 5.0}
