@@ -3,13 +3,10 @@
     celery.events
     ~~~~~~~~~~~~~
 
-    Events are messages sent for actions happening
+    Events is a stream of messages sent for certain actions occurring
     in the worker (and clients if :setting:`CELERY_SEND_TASK_SENT_EVENT`
     is enabled), used for monitoring purposes.
 
-    :copyright: (c) 2009 - 2012 by Ask Solem.
-    :license: BSD, see LICENSE for more details.
-
 """
 from __future__ import absolute_import
 from __future__ import with_statement
@@ -20,15 +17,23 @@ import threading
 
 from collections import deque
 from contextlib import contextmanager
+from copy import copy
 
-from kombu.common import eventloop
-from kombu.entity import Exchange, Queue
-from kombu.messaging import Consumer, Producer
+from kombu import eventloop, Exchange, Queue, Consumer, Producer
+from kombu.utils import cached_property
 
-from ..app import app_or_default
-from ..utils import uuid
+from celery.app import app_or_default
+from celery.utils import uuid
 
-event_exchange = Exchange("celeryev", type="topic")
+event_exchange = Exchange('celeryev', type='topic')
+
+
+def get_exchange(conn):
+    ex = copy(event_exchange)
+    if conn.transport.driver_type == 'redis':
+        # quick hack for Issue #436
+        ex.type = 'fanout'
+    return ex
 
 
 def Event(type, _fields=None, **fields):
@@ -38,8 +43,8 @@ def Event(type, _fields=None, **fields):
 
     """
     event = dict(_fields or {}, type=type, **fields)
-    if "timestamp" not in event:
-        event["timestamp"] = time.time()
+    if 'timestamp' not in event:
+        event['timestamp'] = time.time()
     return event
 
 
@@ -66,9 +71,9 @@ class EventDispatcher(object):
     """
 
     def __init__(self, connection=None, hostname=None, enabled=True,
-            channel=None, buffer_while_offline=True, app=None,
-            serializer=None):
-        self.app = app_or_default(app)
+                 channel=None, buffer_while_offline=True, app=None,
+                 serializer=None):
+        self.app = app_or_default(app or self.app)
         self.connection = connection
         self.channel = channel
         self.hostname = hostname or socket.gethostname()
@@ -81,6 +86,8 @@ class EventDispatcher(object):
         self.on_disabled = set()
 
         self.enabled = enabled
+        if not connection and channel:
+            self.connection = channel.connection.client
         if self.enabled:
             self.enable()
 
@@ -90,9 +97,15 @@ class EventDispatcher(object):
     def __exit__(self, *exc_info):
         self.close()
 
+    def get_exchange(self):
+        if self.connection:
+            return get_exchange(self.connection)
+        else:
+            return get_exchange(self.channel.connection.client)
+
     def enable(self):
-        self.publisher = Producer(self.channel or self.connection.channel(),
-                                  exchange=event_exchange,
+        self.publisher = Producer(self.channel or self.connection,
+                                  exchange=self.get_exchange(),
                                   serializer=self.serializer)
         self.enabled = True
         for callback in self.on_enabled:
@@ -115,10 +128,10 @@ class EventDispatcher(object):
         if self.enabled:
             with self.mutex:
                 event = Event(type, hostname=self.hostname,
-                                    clock=self.app.clock.forward(), **fields)
+                              clock=self.app.clock.forward(), **fields)
                 try:
                     self.publisher.publish(event,
-                                           routing_key=type.replace("-", "."))
+                                           routing_key=type.replace('-', '.'))
                 except Exception, exc:
                     if not self.buffer_while_offline:
                         raise
@@ -138,10 +151,7 @@ class EventDispatcher(object):
     def close(self):
         """Close the event dispatcher."""
         self.mutex.locked() and self.mutex.release()
-        if self.publisher is not None:
-            if not self.channel:  # close auto channel.
-                self.publisher.channel.close()
-            self.publisher = None
+        self.publisher = None
 
 
 class EventReceiver(object):
@@ -157,8 +167,8 @@ class EventReceiver(object):
     """
     handlers = {}
 
-    def __init__(self, connection, handlers=None, routing_key="#",
-            node_id=None, app=None, queue_prefix="celeryev"):
+    def __init__(self, connection, handlers=None, routing_key='#',
+                 node_id=None, app=None, queue_prefix='celeryev'):
         self.app = app_or_default(app)
         self.connection = connection
         if handlers is not None:
@@ -167,15 +177,18 @@ class EventReceiver(object):
         self.node_id = node_id or uuid()
         self.queue_prefix = queue_prefix
         self.queue = Queue('.'.join([self.queue_prefix, self.node_id]),
-                           exchange=event_exchange,
+                           exchange=self.get_exchange(),
                            routing_key=self.routing_key,
                            auto_delete=True,
                            durable=False)
 
+    def get_exchange(self):
+        return get_exchange(self.connection)
+
     def process(self, type, event):
         """Process the received event by dispatching it to the appropriate
         handler."""
-        handler = self.handlers.get(type) or self.handlers.get("*")
+        handler = self.handlers.get(type) or self.handlers.get('*')
         handler and handler(event)
 
     @contextmanager
@@ -204,7 +217,7 @@ class EventReceiver(object):
         list(self.itercapture(limit=limit, timeout=timeout, wakeup=wakeup))
 
     def wakeup_workers(self, channel=None):
-        self.app.control.broadcast("heartbeat",
+        self.app.control.broadcast('heartbeat',
                                    connection=self.connection,
                                    channel=channel)
 
@@ -213,8 +226,8 @@ class EventReceiver(object):
             pass
 
     def _receive(self, body, message):
-        type = body.pop("type").lower()
-        clock = body.get("clock")
+        type = body.pop('type').lower()
+        clock = body.get('clock')
         if clock:
             self.app.clock.adjust(clock)
         self.process(type, Event(type, body))
@@ -225,30 +238,25 @@ class Events(object):
     def __init__(self, app=None):
         self.app = app
 
-    def Receiver(self, connection, handlers=None, routing_key="#",
-            node_id=None):
-        return EventReceiver(connection,
-                             handlers=handlers,
-                             routing_key=routing_key,
-                             node_id=node_id,
-                             app=self.app)
+    @cached_property
+    def Receiver(self):
+        return self.app.subclass_with_self(EventReceiver,
+                                           reverse='events.Receiver')
 
-    def Dispatcher(self, connection=None, hostname=None, enabled=True,
-            channel=None, buffer_while_offline=True):
-        return EventDispatcher(connection,
-                               hostname=hostname,
-                               enabled=enabled,
-                               channel=channel,
-                               app=self.app)
+    @cached_property
+    def Dispatcher(self):
+        return self.app.subclass_with_self(EventDispatcher,
+                                           reverse='events.Dispatcher')
 
+    @cached_property
     def State(self):
-        from .state import State as _State
-        return _State()
+        return self.app.subclass_with_self('celery.events.state:State',
+                                           reverse='events.State')
 
     @contextmanager
     def default_dispatcher(self, hostname=None, enabled=True,
-            buffer_while_offline=False):
-        with self.app.amqp.publisher_pool.acquire(block=True) as pub:
+                           buffer_while_offline=False):
+        with self.app.amqp.producer_pool.acquire(block=True) as pub:
             with self.Dispatcher(pub.connection, hostname, enabled,
                                  pub.channel, buffer_while_offline) as d:
                 yield d
