@@ -2,11 +2,11 @@ from __future__ import absolute_import
 from __future__ import with_statement
 
 try:
-    import unittest
+    import unittest  # noqa
     unittest.skip
     from unittest.util import safe_repr, unorderable_list_difference
 except AttributeError:
-    import unittest2 as unittest
+    import unittest2 as unittest  # noqa
     from unittest2.util import safe_repr, unorderable_list_difference  # noqa
 
 import importlib
@@ -31,9 +31,9 @@ from nose import SkipTest
 from kombu.log import NullHandler
 from kombu.utils import nested
 
-from ..app import app_or_default
-from ..utils.compat import WhateverIO
-from ..utils.functional import noop
+from celery.app import app_or_default
+from celery.utils.compat import WhateverIO
+from celery.utils.functional import noop
 
 from .compat import catch_warnings
 
@@ -110,7 +110,7 @@ class _AssertWarnsContext(_AssertRaisesBaseContext):
             if first_matching is None:
                 first_matching = w
             if (self.expected_regex is not None and
-                not self.expected_regex.search(str(w))):
+                    not self.expected_regex.search(str(w))):
                 continue
             # store warning for later retrieval
             self.warning = w
@@ -119,14 +119,14 @@ class _AssertWarnsContext(_AssertRaisesBaseContext):
             return
         # Now we simply try to choose a helpful failure message
         if first_matching is not None:
-            raise self.failureException('%r does not match %r' %
-                     (self.expected_regex.pattern, str(first_matching)))
+            raise self.failureException(
+                '%r does not match %r' % (
+                    self.expected_regex.pattern, str(first_matching)))
         if self.obj_name:
-            raise self.failureException('%s not triggered by %s'
-                % (exc_name, self.obj_name))
+            raise self.failureException(
+                '%s not triggered by %s' % (exc_name, self.obj_name))
         else:
-            raise self.failureException('%s not triggered'
-                % exc_name)
+            raise self.failureException('%s not triggered' % exc_name)
 
 
 class Case(unittest.TestCase):
@@ -165,6 +165,7 @@ class Case(unittest.TestCase):
         self.fail(self._formatMessage(msg, standard_msg))
 
     def assertItemsEqual(self, expected_seq, actual_seq, msg=None):
+        missing = unexpected = None
         try:
             expected = sorted(expected_seq)
             actual = sorted(actual_seq)
@@ -179,11 +180,13 @@ class Case(unittest.TestCase):
 
         errors = []
         if missing:
-            errors.append('Expected, but missing:\n    %s' % (
-                           safe_repr(missing)))
+            errors.append(
+                'Expected, but missing:\n    %s' % (safe_repr(missing), ),
+            )
         if unexpected:
-            errors.append('Unexpected, but present:\n    %s' % (
-                           safe_repr(unexpected)))
+            errors.append(
+                'Unexpected, but present:\n    %s' % (safe_repr(unexpected), ),
+            )
         if errors:
             standardMsg = '\n'.join(errors)
             self.fail(self._formatMessage(msg, standardMsg))
@@ -192,8 +195,8 @@ class Case(unittest.TestCase):
 class AppCase(Case):
 
     def setUp(self):
-        from ..app import current_app
-        from ..backends.cache import CacheBackend, DummyClient
+        from celery.app import current_app
+        from celery.backends.cache import CacheBackend, DummyClient
         app = self.app = self._current_app = current_app()
         if isinstance(app.backend, CacheBackend):
             if isinstance(app.backend.client, DummyClient):
