@@ -59,8 +59,8 @@ def worker_direct(hostname):
                  auto_delete=True)
 
 
-def warn_deprecated(description=None, deprecation=None, removal=None,
-        alternative=None):
+def warn_deprecated(description=None, deprecation=None,
+                    removal=None, alternative=None):
     ctx = {'description': description,
            'deprecation': deprecation, 'removal': removal,
            'alternative': alternative}
@@ -71,8 +71,8 @@ def warn_deprecated(description=None, deprecation=None, removal=None,
     warnings.warn(w)
 
 
-def deprecated(description=None, deprecation=None, removal=None,
-        alternative=None):
+def deprecated(description=None, deprecation=None,
+               removal=None, alternative=None):
 
     def _inner(fun):
 
@@ -129,7 +129,7 @@ def fun_takes_kwargs(fun, kwlist=[]):
     """
     argspec = getattr(fun, 'argspec', getargspec(fun))
     args, _varargs, keywords, _defaults = argspec
-    if keywords != None:
+    if keywords is not None:
         return kwlist
     return filter(partial(operator.contains, args), kwlist)
 
@@ -189,8 +189,8 @@ def maybe_reraise():
 
 
 def strtobool(term, table={'false': False, 'no': False, '0': False,
-                             'true':  True, 'yes': True,  '1': True,
-                             'on':    True, 'off': False}):
+                           'true': True, 'yes': True, '1': True,
+                           'on': True, 'off': False}):
     if isinstance(term, basestring):
         try:
             return table[term.lower()]
@@ -222,8 +222,8 @@ def gen_task_name(app, name, module_name):
 # > XXX Compat
 from .log import LOG_LEVELS     # noqa
 from .imports import (          # noqa
-        qualname as get_full_cls_name, symbol_by_name as get_cls_by_name,
-        instantiate, import_from_cwd
+    qualname as get_full_cls_name, symbol_by_name as get_cls_by_name,
+    instantiate, import_from_cwd
 )
 from .functional import chunks, noop                    # noqa
 from kombu.utils import cached_property, kwdict, uuid   # noqa
