@@ -8,7 +8,6 @@
 from __future__ import absolute_import
 from __future__ import with_statement
 
-import errno
 import hashlib
 import os
 import select
@@ -19,7 +18,7 @@ from collections import defaultdict
 
 from kombu.utils import eventio
 
-from celery.platforms import ignore_EBADF
+from celery.platforms import ignore_errno
 from celery.utils.imports import module_file
 from celery.utils.log import get_logger
 from celery.utils.threads import bgThread, Event
@@ -69,8 +68,8 @@ def file_hash(filename, algorithm='md5'):
 
 class BaseMonitor(object):
 
-    def __init__(self, files, on_change=None, shutdown_event=None,
-            interval=0.5):
+    def __init__(self, files,
+                 on_change=None, shutdown_event=None, interval=0.5):
         self.files = files
         self.interval = interval
         self._on_change = on_change
@@ -100,7 +99,7 @@ class StatMonitor(BaseMonitor):
     def start(self):
         while not self.shutdown_event.is_set():
             modified = dict((f, mt) for f, mt in self._mtimes()
-                                if self._maybe_modified(f, mt))
+                            if self._maybe_modified(f, mt))
             if modified:
                 self.on_change(modified)
                 self.modify_times.update(modified)
@@ -149,7 +148,7 @@ class KQueueMonitor(BaseMonitor):
         for f, fd in self.filemap.iteritems():
             if fd is not None:
                 poller.unregister(fd)
-                with ignore_EBADF():  # pragma: no cover
+                with ignore_errno('EBADF'):  # pragma: no cover
                     os.close(fd)
         self.filemap.clear()
         self.fdmap.clear()
@@ -210,7 +209,7 @@ implementations = {'kqueue': KQueueMonitor,
                    'inotify': InotifyMonitor,
                    'stat': StatMonitor}
 Monitor = implementations[
-            os.environ.get('CELERYD_FSNOTIFY') or default_implementation()]
+    os.environ.get('CELERYD_FSNOTIFY') or default_implementation()]
 
 
 class Autoreloader(bgThread):
@@ -229,11 +228,12 @@ class Autoreloader(bgThread):
 
     def on_init(self):
         files = self.file_to_module
-        files.update(dict((module_file(sys.modules[m]), m)
-                        for m in self.modules))
+        files.update(dict(
+            (module_file(sys.modules[m]), m) for m in self.modules))
 
-        self._monitor = self.Monitor(files, self.on_change,
-                shutdown_event=self._is_shutdown, **self.options)
+        self._monitor = self.Monitor(
+            files, self.on_change,
+            shutdown_event=self._is_shutdown, **self.options)
         self._hashes = dict([(f, file_hash(f)) for f in files])
 
     def on_poll_init(self, hub):
@@ -247,11 +247,8 @@ class Autoreloader(bgThread):
 
     def body(self):
         self.on_init()
-        try:
+        with ignore_errno('EINTR', 'EAGAIN'):
             self._monitor.start()
-        except OSError, exc:
-            if exc.errno not in (errno.EINTR, errno.EAGAIN):
-                raise
 
     def _maybe_modified(self, f):
         digest = file_hash(f)
